"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.logger = void 0;
exports.init = init;
const winston_1 = __importDefault(require("winston"));
const winston_loki_1 = __importDefault(require("winston-loki"));
const utils_js_1 = require("../utils.js");
const config_js_1 = require("./config.js");
const helper_js_1 = require("./helper.js");
const requestId_js_1 = require("./requestId.js");
function init(config) {
    if (config === undefined) {
        config = {
            LOGGING: process.env.LOGGING,
            LOGGING_TRANSPORT: process.env.LOGGING_TRANSPORT,
            LOGGING_LABELS: process.env.LOGGING_LABELS
        };
    }
    const parsed_config = (0, helper_js_1.parseConfig)(config ?? {});
    const transports = initTransports(parsed_config);
    exports.logger = winston_1.default.createLogger({
        format: winston_1.default.format.combine((0, requestId_js_1.addRequestID)(), winston_1.default.format.json()),
        exitOnError: false,
        levels: config_js_1.logLevelMapping,
        level: parsed_config.LOGGING,
        transports,
    });
    exports.logger.info('Logging initialized', {
        log_level: parsed_config.LOGGING,
        transports: parsed_config.LOGGING_TRANSPORT.map(t => t.transport).join(','),
        labels: parsed_config.LOGGING_LABELS
    });
}
function initTransports(config) {
    return config.LOGGING_TRANSPORT.map(transport => {
        if (transport.transport === 'loki') {
            return new winston_loki_1.default({
                host: transport.host,
                labels: config.LOGGING_LABELS,
                format: winston_1.default.format.json(),
                batching: true,
                interval: 5,
            });
        }
        else if (transport.transport === 'file') {
            return new winston_1.default.transports.File({ filename: transport.filename });
        }
        else if (transport.transport === 'stdout') {
            return new winston_1.default.transports.Console();
        }
        else if (transport.transport === 'stderr') {
            return new winston_1.default.transports.Console({ stderrLevels: ['error', 'fatal'] });
        }
        else {
            (0, utils_js_1.die)('Unknown transport: ' + transport.transport);
            return new winston_1.default.transports.Console();
        }
    });
}
//# sourceMappingURL=logging.js.map