import assert, { fail } from 'assert';
import Mocha from 'mocha';
import { UninitializedRepositoryError } from '../../errors.js';
export function testSuiteFindOne(repositoryTestData) {
    const testSuite = new Mocha.Suite('findOne');
    for (const key in repositoryTestData.entityData) {
        testSuite.addTest(new Mocha.Test(`should find a specific existing model (${key})`, async function () {
            const model = (await repositoryTestData.repository.findOne({
                where: repositoryTestData.getFindOptionsWhere(repositoryTestData.entityData[key].model),
            }));
            assert(model);
            assert(repositoryTestData.compareModels(model, repositoryTestData.entityData[key].model, false));
        }));
    }
    testSuite.addTest(new Mocha.Test('should return null when the model does not exist', async function () {
        const model = await repositoryTestData.repository.findOne({
            where: repositoryTestData.getFindOptionsWhere(),
        });
        assert(model === null);
    }));
    testSuite.addTest(new Mocha.Test('should throw an UninitializedRepositoryError if the repository has not been initialized', async function () {
        const unitializedRepository = new repositoryTestData.RepositoryClass();
        try {
            await unitializedRepository.findOne({});
            fail();
        }
        catch (error) {
            assert(error instanceof UninitializedRepositoryError);
        }
    }));
    return testSuite;
}
//# sourceMappingURL=findOne.spec.js.map